<?php
/**
 * Template Name: Gallery Template 
 * Template Post Type: post, page                                
 * The template for displaying portfolio pages.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Yummy Pro 1.0
 */

get_header(); 
$options = yummy_pro_get_theme_options(); ?>

<section id="portfolio-gallery" class="page-section">
    <div class="wrapper">
    <?php 
    	$categories_id = get_post_meta( $post->ID, 'yummy-pro-gallery-template', true );

    	if( empty( $categories_id ) ) : ?>
    		<div id="primary" class="content-area">
				<main id="main" class="site-main" role="main">
					<?php get_template_part( 'template-parts/content', 'page' ); ?>
				</main><!-- #main -->
			</div><!-- #primary -->
    	<?php else : ?>
	        <nav class="portfolio-filter">
	            <div class="container">
	              	<ul>
	                	<li><a href="#" data-filter="*" class="active"><?php esc_html_e( 'All', 'yummy-pro' ); ?></a></li>
	                	<?php foreach ( $categories_id as $key => $category_id ) {
			                $category_object = get_category( $category_id );
	                  		echo '<li><a href="#" data-filter=".'. esc_attr( $category_object->slug ) .'">'. esc_html( $category_object->name ) .'</a></li>';
		                } ?>
	                </ul>
	            </div><!-- .container -->
	        </nav>
	        <div id="gallery">
	            <div class="portfolio gallery-popup">
	     		<?php
	            	$gallery_args = array(
						'category__in'   => $categories_id,
						'posts_per_page' => absint( get_option( 'posts_per_page', 9 ) ), // Maximum number of posts to show on a page; set in Reading Options.,,
	            	);
	            	$gallery_posts = get_posts( $gallery_args );

	            	if( ! empty( $gallery_posts ) ) :
	            		$index = 1;
	            		foreach ( $gallery_posts as $key => $gallery_post ) {
	        				if( ( $index == 2 ) || ( $index == 8 ) ) {
	                            $item = 2;
	                        }
	                        elseif( $index == 7 ) {
	                            $item = 3;
	                        }
	                        elseif( $index == 9 ) {
	                        	$item = 1;
	                        	$index = 1;
	                        } else{
	                        	$item = 1;
	                        }

		            		$gallery_post_id = $gallery_post->ID;
		            		$img_array = array();
	            			if ( has_post_thumbnail( $gallery_post_id ) ) {
	                            $featured_img = wp_get_attachment_image_src( get_post_thumbnail_id( $gallery_post->ID ), 'medium_large' );
	                            $img_array[0] = $featured_img[0];
	                        } else {
	                            $img_array[0] =  get_template_directory_uri() . '/assets/uploads/no-featured-image-1500x1000.jpg';
	                        }
	                        if ( isset( $img_array ) ) {
	                          	$post_image['img_array'] = $img_array[0];
	                        }
	            			$post_title = get_the_title( $gallery_post_id );
	            			$post_url = get_the_permalink( $gallery_post_id ); 
	            			$post_categories = get_the_category( $gallery_post_id );

	            			$post_category_list = '';
	            			foreach ( $post_categories as $key => $post_category ) {
	            				$post_category_list .= $post_category->slug . ' ';
	            			} ?>
		            		
			              	<div class="portfolio-item item-w<?php echo esc_attr( $item ); ?> <?php echo esc_attr( $post_category_list ); ?>">
			                	<div class="portfolio-featured-image" style="background-image:url( '<?php echo esc_url( $post_image['img_array'] ); ?>' );">
				                  	<div class="black-overlay"></div>
				                  	<div class="portfolio-hover">
				                    	<h4><a href="<?php echo esc_url( $post_url ); ?>"><?php echo esc_html( $post_title ); ?></a></h4>
				                    	<div class="portfolio-icons">
				                      		<a href="<?php echo esc_url( $post_url ); ?>"><i class="fa fa-link"></i></a>
				                      		<a href="<?php echo esc_url( $post_image['img_array'] ); ?>" class="popup"><i class="fa fa-eye"></i></a>
				                    	</div><!-- .portfolio-icons -->
				                  	</div><!-- .portfolio-hover -->       
			                	</div><!-- .portfolio-featured-image -->
			              	</div><!-- .portfolio-item -->
			              	<?php $index++; 
			            } 
			        endif; ?>
	            </div><!-- .portfolio -->
	        </div><!-- #gallery -->

	        <div class="load-more">
	        	<a href="#" id="loadmore" class="more-link fill-black"><?php esc_html_e( 'Load more','yummy-pro' ); ?></a>
	        </div><!-- .load-more -->
     	<?php endif; ?>
    </div><!-- .wrapper -->

    <div class="page-decoration">
        <img src="<?php echo get_template_directory_uri().'/assets/uploads/dish-01.png'; ?>" alt="<?php esc_attr_e( 'Decoration','yummy-pro' ); ?>">
        <img src="<?php echo get_template_directory_uri().'/assets/uploads/dish-02.png'; ?>" alt="<?php esc_attr_e( 'Decoration','yummy-pro' ); ?>">
        <img src="<?php echo get_template_directory_uri().'/assets/uploads/dish-03.png'; ?>" alt="<?php esc_attr_e( 'Decoration','yummy-pro' ); ?>">
        <img src="<?php echo get_template_directory_uri().'/assets/uploads/dish-04.png'; ?>" alt="<?php esc_attr_e( 'Decoration','yummy-pro' ); ?>">
    </div><!-- .page-decoration -->
</section><!-- #portfolio-gallery -->
<?php get_footer();