<?php 
/**
 * Testimonial section
 *
 * This is the template for the content of Testimonial section
 *
 * @package Yummy Pro
 * @since Yummy Pro 1.0
 */
if ( ! function_exists( 'yummy_pro_add_testimonial_section' ) ) :
    /**
    * Add Testimonial section
    *
    *@since Yummy Pro 1.0
    */
    function yummy_pro_add_testimonial_section() {
        // Check if Testimonial is enabled
        $enable_testimonial = apply_filters( 'yummy_pro_section_status', true, 'enable_testimonial' );

        if ( true !== $enable_testimonial ) {
            return false;
        }

        // Get Testimonial section details
        $section_details = array();
        $section_details = apply_filters( 'yummy_pro_filter_testimonial_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render Testimonial section now.
        yummy_pro_render_testimonial_section( $section_details );
    }
endif;
add_action( 'yummy_pro_primary_content_action', 'yummy_pro_add_testimonial_section', 70 );


if ( ! function_exists( 'yummy_pro_get_testimonial_section_details' ) ) :
    /**
    * Testimonial section details.
    *
    * @since Yummy Pro 1.0
    * @param array $input Testimonial section details.
    */
    function yummy_pro_get_testimonial_section_details( $input ) {
        $options = yummy_pro_get_theme_options();
        // Testimonial type
        $testimonial_header_type      = $options['testimonial_header_type'];
        $testimonial_content_type     = $options['testimonial_content_type'];

        $content = array();

        // header section
        switch ( $testimonial_header_type  ) {

            case 'demo':
                $content['header'][0]['title']  = esc_html__( 'They are fond of our food', 'yummy-pro' );
                $content['header'][0]['url']    = '#';
                $content['header'][0]['img']    = get_template_directory_uri().'/assets/uploads/parallax-bg.jpg';
            break;

            case 'custom':
                $content['header'][0]['title'] = ! empty( $options['testimonial_header_title'] ) ? $options['testimonial_header_title'] : '';
                $content['header'][0]['img']   = ! empty( $options['testimonial_header_image'] ) ? $options['testimonial_header_image'] : get_template_directory_uri() . '/assets/uploads/no-featured-image-1500x1000.jpg';
                $content['header'][0]['url']   = ! empty( $options['testimonial_header_link'] ) ? $options['testimonial_header_link'] : '#';
            break;

            case 'page' :
                $id = ( ! empty( $options['testimonial_header_page'] ) ) ? absint( $options['testimonial_header_page'] ) : '';
                $args = array( 
                    'post_type' => 'page',
                    'page_id'   => $id,
                 );
                $posts = get_posts( $args );
                foreach ( $posts as $post ) {
                    $img_array = null;
                    if ( has_post_thumbnail( $post->ID ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full' );
                    } else {
                        $img_array[0] =  get_template_directory_uri() . '/assets/uploads/no-featured-image-1500x1000.jpg';
                    }

                    $content['header'][1]['title'] = get_the_title( $post->ID );
                    $content['header'][1]['url']   = get_the_permalink( $post->ID );
                    $content['header'][1]['img']   = $img_array[0];
                }
            break;
            
        }


        // content section 
        switch ( $testimonial_content_type ) {
          	case 'demo':
                $title = array( 1 => esc_html__( 'Walter White', 'yummy-pro' ), 2 => esc_html__( 'Gret Martinez', 'yummy-pro' ), 3 => esc_html__( 'Michael Laurence', 'yummy-pro' ), 4 => esc_html__( 'Saul Goodman', 'yummy-pro' ) );
                $social_link = array( 1 => esc_url( 'www.facebook.com' ), 2 => esc_url( 'www.twitter.com' ) );
                for ( $i = 1; $i <= 4; $i++ ) {
                    $content['content'][$i]['title']        = $title[$i]; 
                    $content['content'][$i]['url']          = '#'; 
                    $content['content'][$i]['excerpt']      = esc_html__( 'Lorem ipsum dolor sit amet,sectetur scing elit nullam suscipit feugiat.', 'yummy-pro' );
                    $content['content'][$i]['img_array'][0]     = get_template_directory_uri() . '/assets/uploads/testimonial-0' . $i . '.jpg';
                    $content['content'][$i]['img_array'][1]     = 300;
                    $content['content'][$i]['img_array'][2]     = 300; 
                    $content['content'][$i]['social_link']      = $social_link;
                }
          	break;     

          	case 'post':
                $ids = array();
                
                if ( ! empty( $options['testimonial_default_posts'] ) )
                    $ids = ( array ) $options['testimonial_default_posts'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page' => 6,
                );        
            break;

            case 'tp-philosophy-testi':
                $ids = array();
                
                if ( ! empty( $options['tp_testimonial_posts'] ) )
                    $ids = ( array ) $options['tp_testimonial_posts'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'tp-philosophy-testi',
                    'post__in'       => $ids,
                    'posts_per_page' => 6,
                );      

            break;
        }

        if ( 'demo' != $testimonial_content_type ) {
            $posts = get_posts( $args );
            $i = 1;
            foreach ( $posts as $post ) :
                $page_id = $post->ID;
                $img_array = null;
                if ( has_post_thumbnail( $page_id ) ) {
                    $img_array          = wp_get_attachment_image_src( get_post_thumbnail_id( $page_id ), 'post-thumbnail' );
                    $img_array_lg       = wp_get_attachment_image_src( get_post_thumbnail_id( $page_id ), 'full' );
                } else {
                    $img_array[0]       = get_template_directory_uri() . '/assets/uploads/no-featured-image-300x300.jpg';
                    $img_array[1]       = 300;
                    $img_array[2]       = 300;
                }
                $content['content'][$i]['title']        = get_the_title( $page_id );
                $content['content'][$i]['url']          = get_the_permalink( $page_id );
                $content['content'][$i]['excerpt']      = yummy_pro_trim_content( 10, $post );
                $content['content'][$i]['img_array']    = $img_array;
                $content['content'][$i]['id']           = $post->ID;

                $i++;
            endforeach;
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// Testimonial section content details.
add_filter( 'yummy_pro_filter_testimonial_section_details', 'yummy_pro_get_testimonial_section_details' );


if ( ! function_exists( 'yummy_pro_render_testimonial_section' ) ) :
    /**
     * Start Testimonial section
     *
     * @return string Testimonial content
     * @since Yummy Pro 1.0
     *
    */
    function yummy_pro_render_testimonial_section( $content_details = array() ) {
        $options = yummy_pro_get_theme_options();
        $testimonial_content_type     = $options['testimonial_content_type'];

        if ( empty( $content_details ) ) {
          return;
        } 

        if ( ! empty( $content_details['header'] ) ) :
            foreach ( $content_details['header'] as $content ) :?>
                <section id="parallax-3" class="parallax" style="background-image:url( '<?php echo esc_url( $content['img'] ); ?>' );" data-stellar-background-ratio="0.5" data-stellar-vertical-offset="0">
                    <div class="black-overlay"></div>
                    <?php if ( ! empty( $content['title'] ) ) : ?>
                    <div class="wrapper">
                        <header class="entry-header">
                            <h2 class="entry-title color-white">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>">
                                        <?php echo esc_html( $content['title'] );  ?>        
                                    </a>
                            </h2>
                        </header>
                    </div><!--.wrapper-->
                    <?php endif; ?>
                </section><!-- #parallax-3 -->
            <?php endforeach;
        endif;

        if ( ! empty( $content_details['content'] ) ) :
            $index = 1; ?>
            <section id="client-testimonial" class="col-2 team-member">
                <div class="wrapper">
                    <div class="row no-margin">
                    <?php foreach ( $content_details['content'] as $content ) { ?>
                        <div class="column-wrapper">
                            <div class="team-content">
                                <div class="team-content-details">
                                    <h4 class="color-black"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h4>
                                    <?php
                                    if ( 'post' != $testimonial_content_type ) { 
                                        if ( 'demo' != $testimonial_content_type ) { 
                                            if ( has_action( 'tp_philosophy_tools_testimonial_designation_action' ) ) { 
                                                echo '<span class="client-position">';
                                                /*
                                                 * @hooked tp_philosophy_testimonial_designation
                                                */   
                                                do_action( 'tp_philosophy_tools_testimonial_designation_action', $content['id'] );
                                                echo '</span>';
                                            }
                                        }
                                        else {
                                            echo '<span class="client-position">' . esc_html__( 'Celebrity','yummy-pro' ) . '</span>';
                                        }
                                    }
                                    if ( ! empty( $content['excerpt'] ) ) { ?>
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    <?php }
                                    if ( 'post' != $testimonial_content_type ) { 
                                        if ( 'demo' != $testimonial_content_type ) {
                                            if ( has_action( 'tp_philosophy_tools_testimonial_rating_action' ) ) { 
                                                /*
                                                 * @hooked tp_philosophy_testimonial_rating
                                                */   
                                                do_action( 'tp_philosophy_tools_testimonial_rating_action', $content['id'] );
                                            }
                                            if ( has_action( 'tp_philosophy_tools_testimonial_social_links_action' ) ) {
                                                /*
                                                 * @hooked tp_philosophy_testimonial_social_links
                                                */
                                                do_action( 'tp_philosophy_tools_testimonial_social_links_action', $content['id'] );
                                            }
                                        }
                                        else { ?>
                                            <ul class="social-icons">
                                                <li><a href="<?php echo esc_url( 'www.facebook.com' ); ?>"></a></li>
                                                <li><a href="<?php echo esc_url( 'www.twitter.com' ); ?>"></a></li>
                                            </ul><!--.social-icons-->
                                        <?php }
                                    } ?>
                                </div><!--.team-content-details -->
                            </div><!--.team-content-->
                            <div class="featured-image">
                                <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['img_array'][0] ); ?>" width="<?php echo absint( $content['img_array'][1] ); ?>" height="<?php echo absint( $content['img_array'][2] ); ?>"></a>
                            </div><!--.featured-image-->
                        </div><!--.column-wrapper-->
                    <?php $index++; } ?>
                    </div><!--.row-->
                </div><!--.wrapper-->  
            </section><!-- #recent-products -->
        <?php endif;
    }
endif;
